<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryForm" size="small" :inline="true" v-show="showSearch" label-width="100px">
      <el-form-item label="点位名称" prop="pointName">
        <el-input v-model="queryParams.pointName" placeholder="请输入点位名称" clearable @keyup.enter.native="handleQuery" />
      </el-form-item>
      <el-form-item>
        <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">搜索</el-button>
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <!--      <el-col :span="1.5">-->
      <!--        <el-button-->
      <!--          type="primary"-->
      <!--          plain-->
      <!--          icon="el-icon-plus"-->
      <!--          size="mini"-->
      <!--          @click="handleAdd"-->
      <!--        >新增</el-button>-->
      <!--      </el-col>-->
      <el-col :span="1.5">
        <el-button type="success" plain icon="el-icon-edit" size="mini" :disabled="single" @click="handleUpdate"
          v-hasPermi="['point:edit']">修改</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button type="danger" plain icon="el-icon-delete" size="mini" :disabled="multiple" @click="handleDelete"
          v-hasPermi="['point:remove']">删除</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button type="warning" plain icon="el-icon-top" size="mini" @click="handleImportPoint"
          v-hasPermi="['point:import']">导入点位</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button type="danger" plain icon="el-icon-receiving" size="mini" @click="handleEditBatch"
          v-hasPermi="['point:edit']">批量修改</el-button>
      </el-col>
      <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
    </el-row>

    <el-table v-loading="loading" :data="pointList" @selection-change="handleSelectionChange">
      <el-table-column type="selection" width="55" align="center" />
      <el-table-column label="点位名称" prop="pointName" width="200" />
      <el-table-column label="标签" align="center" width="90">
        <template slot-scope="scope">
          <dict-tag :options="dict.type.point_tag" :value="scope.row.pointTags" />
        </template>
      </el-table-column>
      <el-table-column label="运维单位" align="center" prop="unitName" />
      <el-table-column label="监管部门" align="center" prop="deptName" />
      <el-table-column label="运维类别" align="center" prop="category">
        <template slot-scope="scope">
          <div v-if="scope.row.category === 1">视频监控</div>
          <div v-else-if="scope.row.category === 2">车辆识别</div>
          <div v-else-if="scope.row.category === 3">人脸识别</div>
        </template>
      </el-table-column>
      <el-table-column label="备注" align="center" prop="remark" />
      <el-table-column label="操作" align="center" fixed="right" class-name="small-padding fixed-width">
        <template slot-scope="scope">
          <el-button size="mini" type="text" icon="el-icon-edit" @click="handleUpdate(scope.row)"
            v-hasPermi="['point:edit']">修改</el-button>
          <el-button size="mini" type="text" icon="el-icon-delete" @click="handleDelete(scope.row)"
            v-hasPermi="['point:remove']">删除</el-button>
        </template>
      </el-table-column>
    </el-table>

    <pagination v-show="total > 0" :total="total" :page.sync="queryParams.pageNum" :limit.sync="queryParams.pageSize"
      @pagination="getList" />

    <!-- 添加运维点位对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="500px" append-to-body>
      <el-form ref="form" :model="form" :rules="rules" label-width="120px">
        <el-form-item label="点位名称" prop="pointName">
          <el-input v-model="form.pointName" placeholder="请输入点位名称" />
        </el-form-item>
        <el-form-item label="点位标签" prop="pointTag">
          <el-select v-model="form.pointTag" placeholder="点位标签" multiple clearable>
            <el-option v-for="dict in dict.type.point_tag" :key="dict.value" :label="dict.label" :value="dict.value" />
          </el-select>
        </el-form-item>
        <!--        <el-form-item label="点位所在地" prop="region">-->
        <!--          <el-cascader v-model="form.region" :options="regionList" placeholder="点位所在地" :props="props" collapse-tags></el-cascader>-->
        <!--        </el-form-item>-->
        <el-form-item label="设备类型" prop="category">
          <el-select v-model="form.category" placeholder="设备类型">
            <el-option label="人脸识别" value="2" />
            <el-option label="视频监控" value="1" />
            <el-option label="车辆监控" value="3" />
          </el-select>
        </el-form-item>
        <el-form-item label="监管部门" prop="deptId">
          <el-cascader v-model="form.deptId" :options="deptOptions" :show-all-levels="false" clearable
            :props="{ checkStrictly: true }">
          </el-cascader>
        </el-form-item>
        <el-form-item label="运维单位" prop="unitId">
          <el-select v-model="form.unitId" placeholder="运维单位">
            <el-option v-for="item in unitList" :key="item.id" :label="item.value" :value="item.id">
            </el-option>
          </el-select>
        </el-form-item>
        <el-form-item label="点位备注" prop="remark">
          <el-input type="textarea" v-model="form.remark"/>
        </el-form-item>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>

    <!-- 批量修改运维单位 -->
    <el-dialog title="批量修改运维单位" :visible.sync="batchOpen" width="600px" append-to-body>
      <el-form ref="form" :model="batchEditForm" :rules="batchRules" label-width="120px">
        <el-form-item label="点位选择" prop="ids">
          <el-cascader @change="cos" v-model="batchEditForm.ids" :options="regionList" placeholder="请选择区域"
            :props="props" collapse-tags></el-cascader>
        </el-form-item>
        <el-form-item label="运维单位" prop="unitId">
          <el-select v-model="batchEditForm.unitId" placeholder="选择运维单位">
            <el-option v-for="item in unitList" :key="item.id" :label="item.value" :value="item.id">
            </el-option>
          </el-select>
        </el-form-item>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitBatchEdit">确 定</el-button>
        <el-button @click="cancelBatchEdit">取 消</el-button>
      </div>
    </el-dialog>

  </div>
</template>

<script>
import { listPoint, getPoint, delPoint, addPoint, batchEdit, updatePoint } from "@/api/platform/point";
import { unitSelect } from "@/api/platform/unit";
import { getCascader } from '@/api/platform/region'
import { cascader } from '@/api/system/dept'

export default {
  name: "Point",
  dicts: ['point_tag'],
  data() {
    return {
      deptOptions: [],
      // 批量修改表单
      batchEditForm: {
        ids: [],
        unitId: null,
        timezone: null,
      },
      // 批量修改弹窗
      batchOpen: false,
      props: { multiple: true },
      regionList: [],
      // 遮罩层
      loading: true,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 运维点位表格数据
      pointList: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      // 修改弹窗
      editOpen: false,
      // 运维单位
      unitList: [],
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        pointName: null,
        unitId: null,
        status: null,
      },
      // 表单参数
      form: {
      },
      // 表单校验
      rules: {
        pointName: [
          { required: true, message: "点位名称不能为空", trigger: "blur" }
        ],
        pointTag: [
          { required: true, message: "点位标签不能为空", trigger: "change" }
        ],
        deptId: [
          { required: true, message: "监管部门不能为空", trigger: "change" }
        ],
        category: [
          { required: true, message: "设备类型", trigger: "change" }
        ],
      },
      // 批量表单校验
      batchRules: {
        ids: [
          { required: true, message: "请选择点位", trigger: "change" }
        ]
      }
    };
  },
  created() {
    this.getList();
    this.getUnitSelect();
    // this.getCascader();
    this.getDeptCascader();
  },
  methods: {
    // 点位导入
    handleImportPoint() {

    },
    cos(value) {
      console.log(value)
    },
    // 提交批量修改
    submitBatchEdit() {
      this.batchEditForm.ids = this.batchEditForm.ids.map(array => array[array.length - 1]);
      if (this.batchEditForm.timezone) {
        this.batchEditForm.startTime = this.batchEditForm.timezone[0];
        this.batchEditForm.endTime = this.batchEditForm.timezone[1];
      }
    },
    // 取消批量修改
    cancelBatchEdit() {
      this.batchOpen = false;
    },
    // 批量修改
    handleEditBatch() {
      this.batchOpen = true;
    },

    // 获取区县级联
    getCascader() {
      getCascader().then(res => {
        this.regionList = res.data;
      })
    },
    // 获取部门级联
    getDeptCascader() {
      cascader().then(res => {
        this.deptOptions = res.data;
      })
    },

    // 时间选择发生变化
    dateChange() {
      this.tempForm.startTime = this.tempForm.timezone[0];
      this.tempForm.endTime = this.tempForm.timezone[1];
    },
    getUnitSelect() {
      // 运维单位下拉列表
      unitSelect().then((res) => {
        this.unitList = res.data;
      })
    },
    /** 查询运维点位列表 */
    getList() {
      this.loading = true;
      listPoint(this.queryParams).then(response => {
        this.pointList = response.data;
        this.total = response.total;
        this.loading = false;
      });
    },
    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        id: null,
        pointName: null,
        unitId: null,
        deptId: [],
        status: null,
        remark: null,
        createTime: null,
        updateTime: null,
        deleted: null,
        pointTag: []
      };
      this.resetForm("form");
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map(item => item.id)
      this.single = selection.length !== 1
      this.multiple = !selection.length
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset();
      this.open = true;
      this.title = "添加运维点位";
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset();
      const id = row.id || this.ids
      getPoint(id).then(response => {
        this.form = response.data;
        this.form.pointTag = response.data.pointTags;
        this.form.deptId = response.data.deptIds
        this.form.category = this.form.category + ''
        this.open = true;
        this.title = "修改运维点位";
      });
    },
    /** 提交按钮 */
    submitForm() {
      this.$refs['form'].validate(valid => {
        if (valid) {
          if (this.form.deptId && this.form.deptId.length > 0) {
            this.form.deptId = this.form.deptId[this.form.deptId.length - 1]
          }
          let temp = {
            ...this.form,
            category: parseInt(this.form.category)
          };
          if (temp.id != null) {
            updatePoint(temp).then(response => {
              this.$modal.msgSuccess("修改成功");
              this.open = false;
              this.getList();
            });
          } else {
            addPoint(temp).then(response => {
              this.$modal.msgSuccess("新增成功");
              this.open = false;
              this.reset()
              this.getList();
            });
          }
        } else {
          console.log("error")
        }
      })
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const ids = row.id || this.ids;
      this.$modal.confirm('是否确认删除运维点位编号为"' + ids + '"的数据项？').then(function () {
        return delPoint(ids);
      }).then(() => {
        this.getList();
        this.$modal.msgSuccess("删除成功");
      }).catch(() => {
      });
    },
    /** 导出按钮操作 */
    handleExport() {
      this.download('x/point/export', {
        ...this.queryParams
      }, `point_${new Date().getTime()}.xlsx`)
    }
  }
};
</script>

<style scoped>
.col-item {
  margin: 5px 0;
  display: flex;
  flex-direction: row;
  align-content: center;
  justify-content: center;
}
</style>
